@@ -39,6 +39,7 @@ from semantic_release.cli.masking_filter import MaskingFilter
 from semantic_release.commit_parser import (
     AngularCommitParser,
     CommitParser,
+    ConventionalCommitParser,
     EmojiCommitParser,
     ParseResult,
     ParserOptions,
@@ -54,7 +55,6 @@ from semantic_release.errors import (
     ParserLoadError,
 )
 from semantic_release.helpers import dynamic_import
-from semantic_release.hvcs.remote_hvcs_base import RemoteHvcsBase
 from semantic_release.version.declaration import (
     PatternVersionDeclaration,
     TomlVersionDeclaration,
@@ -74,6 +74,7 @@ class HvcsClient(str, Enum):
 
 
 _known_commit_parsers: Dict[str, type[CommitParser]] = {
+    "conventional": ConventionalCommitParser,
     "angular": AngularCommitParser,
     "emoji": EmojiCommitParser,
     "scipy": ScipyCommitParser,
@@ -287,15 +288,18 @@ class RemoteConfig(BaseModel):
 
     def _get_default_token(self) -> str | None:
         hvcs_client_class = _known_hvcs[self.type]
-        default_hvcs_instance = hvcs_client_class("git@example.com:owner/project.git")
-        if not isinstance(default_hvcs_instance, RemoteHvcsBase):
-            return None
 
-        default_token_name = default_hvcs_instance.DEFAULT_ENV_TOKEN_NAME
-        if not default_token_name:
-            return None
+        default_token_name = (
+            getattr(hvcs_client_class, "DEFAULT_ENV_TOKEN_NAME")  # noqa: B009
+            if hasattr(hvcs_client_class, "DEFAULT_ENV_TOKEN_NAME")
+            else ""
+        )
 
-        return EnvConfigVar(env=default_token_name).getvalue()
+        return (
+            EnvConfigVar(env=default_token_name).getvalue()
+            if default_token_name
+            else None
+        )
 
     @model_validator(mode="after")
     def check_url_scheme(self) -> Self:
@@ -353,7 +357,7 @@ class RawConfig(BaseModel):
         env="GIT_COMMIT_AUTHOR", default=DEFAULT_COMMIT_AUTHOR
     )
     commit_message: str = COMMIT_MESSAGE
-    commit_parser: NonEmptyString = "angular"
+    commit_parser: NonEmptyString = "conventional"
     # It's up to the parser_options() method to validate these
     commit_parser_options: Dict[str, Any] = {}
     logging_use_named_masks: bool = False
@@ -412,6 +416,22 @@ class RawConfig(BaseModel):
             )
         return val
 
+    @field_validator("commit_parser", mode="after")
+    @classmethod
+    def angular_commit_parser_deprecation_warning(cls, val: str) -> str:
+        if val == "angular":
+            log.warning(
+                str.join(
+                    " ",
+                    [
+                        "The 'angular' parser is deprecated and will be removed in v11.",
+                        "The Angular parser is being renamed to the conventional commit parser,",
+                        "which is selected by switching the 'commit_parser' value to 'conventional'.",
+                    ],
+                )
+            )
+        return val
+
     @field_validator("build_command_env", mode="after")
     @classmethod
     def remove_whitespace(cls, val: list[str]) -> list[str]:
@@ -645,6 +665,17 @@ class RuntimeContext:
                 if raw.commit_parser in _known_commit_parsers
                 else dynamic_import(raw.commit_parser)
             )
+        except ValueError as err:
+            raise ParserLoadError(
+                str.join(
+                    "\n",
+                    [
+                        f"Unrecognized commit parser value: {raw.commit_parser!r}.",
+                        str(err),
+                        "Unable to load the given parser! Check your configuration!",
+                    ],
+                )
+            ) from err
         except ModuleNotFoundError as err:
             raise ParserLoadError(
                 str.join(
@@ -861,6 +892,7 @@ class RuntimeContext:
             changelog_excluded_commit_patterns=changelog_excluded_commit_patterns,
             # TODO: change when we have other styles per parser
             # changelog_style=changelog_style,
+            # TODO: Breaking Change v10, change to conventional
             changelog_style="angular",
             changelog_output_format=raw.changelog.default_templates.output_format,
             prerelease=branch_config.prerelease,
